==> nextcloud-28.0.3.tgz: nextcloud/apps/firstrunwizard/l10n/vi.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Welcome to {cloudName}!" : "Chào mừng đến với {cloudName}!",
    "Privacy" : "Bảo mật",
    "Community" : "Cộng đồng",
    "First run wizard" : "Trình hướng dẫn chạy lần đầu",
    "Add your profile information! For example your email is needed to receive notifications." : "Thêm thông tin hồ sơ của bạn! Ví dụ: email của bạn là cần thiết để nhận thông báo.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Thêm thông tin hồ sơ của bạn! Ví dụ: email của bạn là cần thiết để nhận thông báo và đặt lại mật khẩu của bạn.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Thêm thông tin hồ sơ của bạn! Đặt ảnh hồ sơ và tên đầy đủ để dễ nhận biết hơn trên tất cả các tính năng.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Thêm thông tin hồ sơ của bạn! Đặt tên đầy đủ để dễ dàng nhận biết hơn trên tất cả các tính năng.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Thêm thông tin hồ sơ của bạn! Đặt ảnh hồ sơ để nhận dạng dễ dàng hơn trên tất cả các tính năng.",
    "App recommendation: Nextcloud Calendar" : "Đề xuất ứng dụng: Lịch",
    "Schedule work & meetings, synced with all your devices." : "Lên lịch làm việc và cuộc họp, đồng bộ hóa với tất cả các thiết bị của bạn.",
    "App recommendation: Nextcloud Contacts" : "Đề xuất ứng dụng: Danh bạ",
    "Keep your colleagues and friends in one place without leaking their private info." : "Giữ đồng nghiệp và bạn bè của bạn ở một nơi mà không làm rò rỉ thông tin cá nhân của họ.",
    "App recommendation: Nextcloud Mail" : "Đề xuất ứng dụng: Mail",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Ứng dụng email đơn giản được tích hợp độc đáo với Tệp, Danh bạ và Lịch.",
    "App recommendation: Tasks" : "Đề xuất ứng dụng: Tasks",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Đồng bộ hóa các tác vụ từ nhiều thiết bị khác nhau với Cloud của bạn và chỉnh sửa chúng trực tuyến.",
    "App recommendation: Deck" : "Đề xuất ứng dụng: Deck",
    "Kanban style organization for personal planning and team projects." : "Tổ chức theo phong cách Kanban để lập kế hoạch cá nhân và dự án nhóm",
    "App recommendation: Forms" : "Đề xuất ứng dụng: Biểu mẫu",
    "Simple surveys and questionnaires, self-hosted" : "Các khảo sát và bảng câu hỏi đơn giản, tự lưu trữ",
    "App recommendation: Recognize" : "Đề xuất ứng dụng: Nhận biết",
    "Smart media tagging for Nextcloud" : "Gắn thẻ phương tiện thông minh",
    "App recommendation: Group folders" : "Đề xuất ứng dụng: Nhóm thư mục",
    "Admin-configured folders shared by everyone in a group." : "Các thư mục do quản trị viên định cấu hình được chia sẻ bởi mọi người trong nhóm.",
    "About" : "Thông tin",
    "A welcome and introduction wizard for Nextcloud" : "Trình hướng dẫn chào mừng và giới thiệu",
    "Get the apps to sync your files" : "Nhận ứng dụng để đồng bộ file của bạn",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s cho phép bạn truy cập vào các tập tin của mình mọi lúc mọi nơi. Ứng dụng khách trên máy tính để bàn và thiết bị di động dễ sử dụng của chúng tôi có sẵn cho tất cả các nền tảng chính với chi phí bằng 0.",
    "Desktop client" : "Máy khách để bàn",
    "iOS app" : "Ứng dụng IOS",
    "Connect other apps to %s" : "Kết nối các ứng dụng khác với %s",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Ngoài ứng dụng dành cho thiết bị di động và máy tính để bàn, bạn có thể kết nối bất kỳ phần mềm nào khác hỗ trợ giao thức WebDAV/CalDAV/CardDAV với %s.",
    "Connect your calendar" : "Kết nối lịch của bạn",
    "Connect your contacts" : "Kết nối danh bạ của bạn",
    "Access files via WebDAV" : "Truy cập file qua WebDAV",
    "Download macOS/iOS configuration profile" : "Tải xuống hồ sơ cấu hình macOS/iOS",
    "Server address" : "Địa chỉ máy chủ",
    "Use this link to connect your apps and desktop client to this server:" : "Sử dụng liên kết này để kết nối ứng dụng và máy khách để bàn của bạn với máy chủ này:",
    "Copy link" : "Sao chép liên kết",
    "Copied!" : "Đã sao chép!",
    "Not supported!" : "Không hỗ trợ!",
    "Press ⌘-C to copy." : "Bấm ⌘-C để sao chép.",
    "Press Ctrl-C to copy." : "Bấm Ctrl-C để sao chép.",
    "Start using {cloudName}" : "Bắt đầu sử dụng {cloudName}",
    "Extend your cloud" : "Mở rộng đám mây của bạn",
    "Collaboration apps for document editing" : "Ứng dụng cộng tác để chỉnh sửa tài liệu",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Các tính năng bảo mật và xác thực như xác thực hai yếu tố, bảo vệ SSO và ransomware",
    "Many others like a music player, a password manager, a kanban app, a download manager or a Markdown editor" : "Nhiều ứng dụng khác như trình phát nhạc, trình quản lý mật khẩu, ứng dụng kanban, trình quản lý tải xuống hoặc trình chỉnh sửa Markdown",
    "Browse the App Store" : "Duyệt qua App Store",
    "Stay in sync" : "Luôn đồng bộ hóa",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud cho phép bạn truy cập vào các tập tin của mình mọi lúc mọi nơi.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Ứng dụng khách trên máy tính để bàn và thiết bị di động dễ sử dụng của chúng tôi có sẵn cho tất cả các nền tảng chính với chi phí bằng 0!",
    "Connect your desktop apps to %s" : "Kết nối ứng dụng máy tính để bàn của bạn với %s",
    "Get help" : "Được giúp đỡ",
    "Start contributing" : "Bắt đầu đóng góp",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Bạn có muốn nhận được một cải tiến nhất định trong Cloud không? Bạn có tìm thấy một vấn đề? Bạn có muốn giúp dịch, quảng bá hoặc tài liệu Cloud không?",
    "Become part of the Community" : "Trở thành một phần của cộng đồng",
    "Enterprise support" : "Hỗ trợ doanh nghiệp",
    "If you run Nextcloud in a mission critical environment where security and compliance are important, you need the certainty of Nextcloud Enterprise." : "Nếu bạn chạy Nextcloud trong môi trường quan trọng, nơi bảo mật và tuân thủ là quan trọng, bạn cần có sự chắc chắn của Nextcloud Enterprise.",
    "Get more information" : "Có thêm thông tin",
    "User manual" : "Hướng dẫn sử dụng",
    "Admin manual" : "Hướng dẫn quản trị",
    "Developer manual" : "Hướng dẫn dành cho nhà phát triển",
    "You can also ask for help in our community support channels:" : "Bạn cũng có thể yêu cầu trợ giúp trong các kênh hỗ trợ cộng đồng của chúng tôi:",
    "A safe home for all your data" : "Một ngôi nhà an toàn cho tất cả dữ liệu của bạn",
    "Host your data and files where you decide" : "Lưu trữ dữ liệu và tệp của bạn ở nơi bạn quyết định",
    "Open standards and interoperability" : "Các tiêu chuẩn mở và khả năng tương tác",
    "Learn more about %s" : "Tìm hiểu thêm về %s",
    "This Nextcloud is on version %s" : "Nextcloud này đang ở phiên bản %s"
},
"nplurals=1; plural=0;");

==> nextcloud-29.0.5.tgz: nextcloud/apps/firstrunwizard/l10n/vi.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Trình hướng dẫn chạy lần đầu",
    "Add your profile information! For example your email is needed to receive notifications." : "Thêm thông tin hồ sơ của bạn! Ví dụ: email của bạn là cần thiết để nhận thông báo.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Thêm thông tin hồ sơ của bạn! Ví dụ: email của bạn là cần thiết để nhận thông báo và đặt lại mật khẩu của bạn.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Thêm thông tin hồ sơ của bạn! Đặt ảnh hồ sơ và tên đầy đủ để dễ nhận biết hơn trên tất cả các tính năng.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Thêm thông tin hồ sơ của bạn! Đặt tên đầy đủ để dễ dàng nhận biết hơn trên tất cả các tính năng.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Thêm thông tin hồ sơ của bạn! Đặt ảnh hồ sơ để nhận dạng dễ dàng hơn trên tất cả các tính năng.",
    "App recommendation: Nextcloud Calendar" : "Đề xuất ứng dụng: Lịch",
    "Schedule work & meetings, synced with all your devices." : "Lên lịch làm việc và cuộc họp, đồng bộ hóa với tất cả các thiết bị của bạn.",
    "App recommendation: Nextcloud Contacts" : "Đề xuất ứng dụng: Danh bạ",
    "Keep your colleagues and friends in one place without leaking their private info." : "Giữ đồng nghiệp và bạn bè của bạn ở một nơi mà không làm rò rỉ thông tin cá nhân của họ.",
    "App recommendation: Nextcloud Mail" : "Đề xuất ứng dụng: Mail",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Ứng dụng email đơn giản được tích hợp độc đáo với Tệp, Danh bạ và Lịch.",
    "App recommendation: Tasks" : "Đề xuất ứng dụng: Tasks",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Đồng bộ hóa các tác vụ từ nhiều thiết bị khác nhau với Cloud của bạn và chỉnh sửa chúng trực tuyến.",
    "App recommendation: Deck" : "Đề xuất ứng dụng: Deck",
    "Kanban style organization for personal planning and team projects." : "Tổ chức theo phong cách Kanban để lập kế hoạch cá nhân và dự án nhóm",
    "App recommendation: Forms" : "Đề xuất ứng dụng: Biểu mẫu",
    "Simple surveys and questionnaires, self-hosted" : "Các khảo sát và bảng câu hỏi đơn giản, tự lưu trữ",
    "App recommendation: Recognize" : "Đề xuất ứng dụng: Nhận biết",
    "Smart media tagging for Nextcloud" : "Gắn thẻ phương tiện thông minh",
    "App recommendation: Group folders" : "Đề xuất ứng dụng: Nhóm thư mục",
    "Admin-configured folders shared by everyone in a group." : "Các thư mục do quản trị viên định cấu hình được chia sẻ bởi mọi người trong nhóm.",
    "Connect your calendar" : "Kết nối lịch của bạn",
    "Connect your contacts" : "Kết nối danh bạ của bạn",
    "Access files via WebDAV" : "Truy cập file qua WebDAV",
    "Download macOS/iOS configuration profile" : "Tải xuống hồ sơ cấu hình macOS/iOS",
    "Desktop client" : "Máy khách để bàn",
    "iOS app" : "Ứng dụng IOS",
    "A welcome and introduction wizard for Nextcloud" : "Trình hướng dẫn chào mừng và giới thiệu",
    "Close" : "Đóng",
    "Welcome to {cloudName}!" : "Chào mừng đến với {cloudName}!",
    "Privacy" : "Bảo mật",
    "Community" : "Cộng đồng",
    "Get the apps to sync your files" : "Nhận ứng dụng để đồng bộ file của bạn",
    "Server address" : "Địa chỉ máy chủ",
    "Use this link to connect your apps and desktop client to this server:" : "Sử dụng liên kết này để kết nối ứng dụng và máy khách để bàn của bạn với máy chủ này:",
    "Read more" : "Đọc thêm",
    "Copied!" : "Đã sao chép!",
    "Not supported!" : "Không hỗ trợ!",
    "Press ⌘-C to copy." : "Bấm ⌘-C để sao chép.",
    "Press Ctrl-C to copy." : "Bấm Ctrl-C để sao chép.",
    "About" : "Thông tin",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s cho phép bạn truy cập vào các tập tin của mình mọi lúc mọi nơi. Ứng dụng khách trên máy tính để bàn và thiết bị di động dễ sử dụng của chúng tôi có sẵn cho tất cả các nền tảng chính với chi phí bằng 0.",
    "Connect other apps to %s" : "Kết nối các ứng dụng khác với %s",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Ngoài ứng dụng dành cho thiết bị di động và máy tính để bàn, bạn có thể kết nối bất kỳ phần mềm nào khác hỗ trợ giao thức WebDAV/CalDAV/CardDAV với %s.",
    "Copy link" : "Sao chép liên kết"
},
"nplurals=1; plural=0;");
